@@ -13,6 +13,18 @@ void freememory(void){
 }// cleanup
 }//extern "C"
 
+static const R_CMethodDef CEntries[] = {
+    {"freememory", (DL_FUNC) &freememory,  0},
+    {"tree",       (DL_FUNC) &tree,       21},
+    {NULL, NULL, 0}
+};
+
+void R_init_evtree(DllInfo *dll)
+{
+    R_registerRoutines(dll, CEntries, NULL, NULL, NULL);
+    R_useDynamicSymbols(dll, FALSE);
+}
+
 static void chkIntFn(void *dummy) {
      R_CheckUserInterrupt();
 }
@@ -40,7 +52,7 @@ Container::Container(int* R_nInstances, int* R_nVariables, int *R_varType, doubl
     this->probSplit = *R_pSplit + this->probMutateMinor;
     this->probPrune = *R_pPrune + this->probSplit;
     this->probCrossover = *R_pCrossover + this->probPrune;
-    this->elitismRange = imax2((int)ceil((double)(this->nTrees/20.0)),2);
+	this->elitismRange = imax2((int)std::ceil((double)(this->nTrees/20.0)),2);
     this->nTrees +=  this->elitismRange;
     this->method = *R_method;
     this->elitismList = new int[this->elitismRange];
@@ -251,7 +263,7 @@ double Container::pruneNode(int treeNumber){
         if(nodeNumber <= 0)
             return -1;
 
-	int parent= (int) floorf((nodeNumber-1)/2);
+	int parent= (int) std::floor((nodeNumber-1)/2);
 	int oldSplitV = this->trees[treeNumber]->splitV[nodeNumber];
 	double oldSplitP = this->trees[treeNumber]->splitP[nodeNumber];
 	this->trees[treeNumber]->splitV[nodeNumber] = -999999;
@@ -283,9 +295,9 @@ double Container::pruneNode(int treeNumber){
         }else if(accept == -1){ // reverse prune due to performance reasons
             this->trees[treeNumber]->nNodes++;
             if(nodeNumber%2 == 0 ) {// add Child back to parent
-                    this->trees[treeNumber]->nodes[(int) floorf((nodeNumber-1) / 2)]->rightChild = this->trees[treeNumber]->nodes[nodeNumber];
+                    this->trees[treeNumber]->nodes[(int) std::floor((nodeNumber-1) / 2)]->rightChild = this->trees[treeNumber]->nodes[nodeNumber];
             }else{
-                    this->trees[treeNumber]->nodes[(int) floorf((nodeNumber-1) / 2)]->leftChild = this->trees[treeNumber]->nodes[nodeNumber];
+                    this->trees[treeNumber]->nodes[(int) std::floor((nodeNumber-1) / 2)]->leftChild = this->trees[treeNumber]->nodes[nodeNumber];
             }
             this->trees[treeNumber]->splitV[nodeNumber] = oldSplitV;
             this->trees[treeNumber]->splitP[nodeNumber] = oldSplitP;
@@ -314,7 +326,7 @@ int Container::pruneAllNodes(int treeNumber){
     oldPerformance = this->trees[treeNumber]->performance;
         if(this->trees[treeNumber]->nNodes > 2){
             for(int nodeNumber = 1; nodeNumber*2+2 < this->maxNode; nodeNumber++){
-                int parent = (int) floorf((nodeNumber-1)/2);
+                int parent = (int) std::floor((nodeNumber-1)/2);
                 if( this->trees[treeNumber]->splitV[nodeNumber] >= 0 &&
                     this->trees[treeNumber]->splitV[nodeNumber*2+1] < 0 &&
                     this->trees[treeNumber]->splitV[nodeNumber*2+2] < 0 && parent >= 0){
@@ -407,11 +419,11 @@ double Container::splitNode(int treeNumber){
                         }
 
                         if(terminalNode % 2 == 0 ){ // add child to parent
-                                this->trees[treeNumber]->nodes[(int) floorf((terminalNode-1)/2) ]->rightChild = this->trees[treeNumber]->nodes[terminalNode];
+                                this->trees[treeNumber]->nodes[(int) std::floor((terminalNode-1)/2) ]->rightChild = this->trees[treeNumber]->nodes[terminalNode];
                         }else{
-                                this->trees[treeNumber]->nodes[(int) floorf((terminalNode-1)/2) ]->leftChild = this->trees[treeNumber]->nodes[terminalNode];
+                                this->trees[treeNumber]->nodes[(int) std::floor((terminalNode-1)/2) ]->leftChild = this->trees[treeNumber]->nodes[terminalNode];
                         }
-                        flagValid = this->evaluateTree(treeNumber, false, (int) floorf((terminalNode-1)/2) ) ;
+                        flagValid = this->evaluateTree(treeNumber, false, (int) std::floor((terminalNode-1)/2) ) ;
                     }
                 }
             }
@@ -427,7 +439,7 @@ double Container::splitNode(int treeNumber){
                }else{
                       this->trees[treeNumber]->splitV[terminalNode] = -999999;
                }
-               if(this->evaluateTree(treeNumber, false , (int) floorf((terminalNode - 1) / 2) ) == false) {
+               if(this->evaluateTree(treeNumber, false , (int) std::floor((terminalNode - 1) / 2) ) == false) {
                       // cout << "warning: invalid tree is replaced by a random tree (10) " << endl;
                       this->overwriteTree(treeNumber);
                       return -10;
@@ -775,19 +787,19 @@ void Container::randomSplitVariable(int treeNumber, int nodeNumber){
 bool Container::randomSplitPoint(int treeNumber, int nodeNumber){
      // assigns a random split points
      // used by splitNode() and mutateNode() if the isMinor is set to false
-    if(this->variables[abs(this->trees[treeNumber]->splitV[nodeNumber])]->isCat == false){
+    if(this->variables[std::abs(this->trees[treeNumber]->splitV[nodeNumber])]->isCat == false){
 
         int localInstances = 0;
         if(nodeNumber%2 == 0 ){ // add Child to parent and remove number of terminal instances
-             localInstances = this->trees[treeNumber]->nodes[(int) floorf((nodeNumber-1)/2) ]->sumRightLocalWeights;
+             localInstances = this->trees[treeNumber]->nodes[(int) std::floor((nodeNumber-1)/2) ]->sumRightLocalWeights;
         }else{
-             localInstances = this->trees[treeNumber]->nodes[(int) floorf((nodeNumber-1)/2) ]->sumLeftLocalWeights;
+             localInstances = this->trees[treeNumber]->nodes[(int) std::floor((nodeNumber-1)/2) ]->sumLeftLocalWeights;
         }
         if(localInstances < this->minSplit)
             return false;
 
         double min = 1;
-        double max = (this->variables[abs(this->trees[treeNumber]->splitV[nodeNumber]) ]->nCats)-1;
+        double max = (this->variables[std::abs(this->trees[treeNumber]->splitV[nodeNumber]) ]->nCats)-1;
         int randomSplitPoint = 0;
         double randomNumber = 0.0;
 
@@ -796,14 +808,14 @@ bool Container::randomSplitPoint(int treeNumber, int nodeNumber){
             for(int i = 0; i < 12; i++){
          	   randomNumber += (((double) Tree::getUnifRandNumber(1000))+1.) / 1000.0;
             }
-            randomSplitPoint = (int)fround(((randomNumber-6)*(max-min)/2.0)+( (max+min)/2.0 ),5);
+            randomSplitPoint = (int)(round((((randomNumber-6)*(max-min)/2.0)+( (max+min)/2.0))*10000))/10000;
         }      
        
         if(randomSplitPoint < min || randomSplitPoint > max){
-              randomSplitPoint = (int)fround((min+max)/2.0,5);
+              randomSplitPoint = (int)round(((min+max)/2.0)*10000)/10000;
         }
 
-        this->trees[treeNumber]->splitP[nodeNumber] = this->variables[ abs(this->trees[treeNumber]->splitV[nodeNumber]) ]->sortedValues[randomSplitPoint] ;
+        this->trees[treeNumber]->splitP[nodeNumber] = this->variables[ std::abs(this->trees[treeNumber]->splitV[nodeNumber]) ]->sortedValues[randomSplitPoint] ;
         return true;
     }
     this->trees[treeNumber]->splitP[nodeNumber] = -999999;
@@ -821,7 +833,7 @@ bool Container::changeSplitPoint(int treeNumber, int nodeNumber){
         int oldPos = 0;
         bool flag = false;
         for(int i = 0; i < (this->variables[ this->trees[treeNumber]->splitV[nodeNumber] ]->nCats) && flag == false; i++){
-             if(this->trees[treeNumber]->splitP[nodeNumber] == this->variables[ abs(this->trees[treeNumber]->splitV[nodeNumber]) ]->sortedValues[i]){
+             if(this->trees[treeNumber]->splitP[nodeNumber] == this->variables[ std::abs(this->trees[treeNumber]->splitV[nodeNumber]) ]->sortedValues[i]){
                 oldPos = i;
                 flag = true;
              }
@@ -839,9 +851,9 @@ bool Container::changeSplitPoint(int treeNumber, int nodeNumber){
         int randomSplitPoint= oldPos+randomNumber;
 
         if(randomSplitPoint < mini || randomSplitPoint > maxi){
-            randomSplitPoint = (int)fround((mini+maxi)/2.0,5);
+            randomSplitPoint = (int)round(((mini+maxi)/2.0)*10000)/10000;
         }
-        this->trees[treeNumber]->splitP[nodeNumber] = this->variables[ abs(this->trees[treeNumber]->splitV[nodeNumber]) ]->sortedValues[randomSplitPoint];
+        this->trees[treeNumber]->splitP[nodeNumber] = this->variables[ std::abs(this->trees[treeNumber]->splitV[nodeNumber]) ]->sortedValues[randomSplitPoint];
     return true;
 } // end changeSplitPoint
 
